Please see [https://docs.mlcommons.org/cm4mlops/scripts/AI-ML-frameworks/install-qaic-compute-sdk-from-src](https://docs.mlcommons.org/cm4mlops/scripts/AI-ML-frameworks/install-qaic-compute-sdk-from-src) for the documentation of this CM script.
